@@ -1,3 +1,5 @@
+import os
+
 from easyDataverse import Dataset
 from pyDaRUS.metadatablocks import Citation
 from pyDaRUS.metadatablocks import EnzymeMl
@@ -5,4 +7,7 @@ from pyDaRUS.metadatablocks import EngMeta
 from pyDaRUS.metadatablocks import CodeMeta
 from pyDaRUS.metadatablocks import Archive
 from pyDaRUS.metadatablocks import Process
-from pyDaRUS.metadatablocks import Privacy
\ No newline at end of file
+from pyDaRUS.metadatablocks import Privacy
+
+# Add the lib_name to the operating systems env
+os.environ["EASYDATAVERSE_LIB_NAME"] = "pyDaRUS"
\ No newline at end of file
